#!/bin/sh

LISTENERSERVICE='listenerservice'

if [ -f private.pem -o -f private.der ]; then
    echo A private key has already been generated here. If you really
    echo want to generate a new one, please rm the old one first.
    exit 1
fi

OPENSSL=`which openssl`
BASE64=`which base64`

if [ "x${OPENSSL}" = "x" -o "x${BASE64}" = "x" ]; then
    echo This script requires the openssl and base64 commands on your
    echo path.
    exit 1
fi

ME=`id -un`
if [ ! \( "x$ME" = "xroot" -o "x$ME" = "x${LISTENERSERVICE}" \) ]; then
    echo This script must be run as root or $LISTENERSERVICE
    exit 1
fi

if [ ! -w . ]; then
    echo Unable to write in this directory. Check permissions.
    exit 1
fi

$OPENSSL genrsa -out private.pem 2048
chmod 600 private.pem
$OPENSSL pkcs8 -topk8 -in private.pem -outform DER -out private.der -nocrypt
chmod 600 private.der
$OPENSSL rsa -in private.pem -pubout -outform DER -out public.der
$BASE64 < public.der > public.b64

id listenerservice >/dev/null 2>&1
if [ "x$?" = "x0" ]; then
    chown listenerservice:listenerservice private.pem private.der public.der public.b64
else
    echo listenerservice user not found. Not changing ownership of key files.
fi